# Getting Started: Building Your IT Component Inventory
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/getting-started-building-your-it-component-inventory#overview)
  * [Building Your IT Component Inventory](https://help.sap.com/docs/leanix/ea/getting-started-building-your-it-component-inventory#building-your-it-component-inventory)
  * [Creating IT Component Fact Sheets Manually](https://help.sap.com/docs/leanix/ea/getting-started-building-your-it-component-inventory#creating-it-component-fact-sheets-manually)
  * [Importing IT Components Using an Excel File](https://help.sap.com/docs/leanix/ea/getting-started-building-your-it-component-inventory#importing-it-components-using-an-excel-file)
  * [Importing IT Components Using Inventory Builder](https://help.sap.com/docs/leanix/ea/getting-started-building-your-it-component-inventory#importing-it-components-using-inventory-builder)
  * [Importing IT Components Using SAP Discovery Feature](https://help.sap.com/docs/leanix/ea/getting-started-building-your-it-component-inventory#importing-it-components-using-sap-discovery-feature)
  * [Importing IT Components Using Self-Built Software Discovery Feature](https://help.sap.com/docs/leanix/ea/getting-started-building-your-it-component-inventory#importing-it-components-using-self-built-software-discovery-feature)
  * [Importing IT Components Through ServiceNow Integration](https://help.sap.com/docs/leanix/ea/getting-started-building-your-it-component-inventory#importing-it-components-through-servicenow-integration)


View all
A getting-started guide that walks you through building and enriching your IT component inventory in SAP LeanIX Technology Risk and Compliance
